<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>AboutDialog</name>
    <message>
        <source>cuteTube-QML - 0.6.1</source>
        <translation type="obsolete">cuteTube-QML - 0.6.1</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.0</source>
        <translation type="obsolete">cuteTube-QML - 0.7.0</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.1</source>
        <translation type="obsolete">cuteTube-QML - 0.7.1</translation>
    </message>
    <message>
        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation type="obsolete">Клиент YouTube для Nokia N900. Это экспериментальный выпуск на QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.3</source>
        <translation type="obsolete">cuteTube-QML - 0.7.3</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.5</source>
        <translation type="obsolete">cuteTube-QML - 0.7.5</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.6</source>
        <translation type="obsolete">cuteTube-QML - 0.7.6</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.7</source>
        <translation type="obsolete">cuteTube-QML - 0.7.7</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.8.0</source>
        <translation type="obsolete">cuteTube-QML - 0.8.0</translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="44"/>
        <source>cuteTube-QML - 0.8.2</source>
        <translation type="unfinished">cuteTube-QML - 0.8.2</translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="56"/>
        <source>A feature-rich YouTube client enabling browsing, playback and download of videos, plus account management. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountDetailsDialog</name>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="10"/>
        <location filename="../AccountDetailsDialog.qml" line="26"/>
        <source>New Account</source>
        <translation>Добавить Аккаунт</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="15"/>
        <source>Edit Account</source>
        <translation>Редактировать Аккаунт</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="46"/>
        <source>Database error. Unable to save account</source>
        <translation>Ошибка базы данных. Невозможно сохранить аккаунт</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="82"/>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="95"/>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="108"/>
        <source>Default?</source>
        <translation>По Умолчанию?</translation>
    </message>
</context>
<context>
    <name>AccountsDialog</name>
    <message>
        <location filename="../AccountsDialog.qml" line="79"/>
        <source>YouTube Accounts</source>
        <translation>Аккаунты YouTube</translation>
    </message>
</context>
<context>
    <name>AddCommentDialog</name>
    <message>
        <location filename="../AddCommentDialog.qml" line="6"/>
        <source>Add Comment</source>
        <translation>Добавить Комментарий</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="15"/>
        <source>Share Via </source>
        <translation>Поделиться В</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="60"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="74"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="111"/>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
</context>
<context>
    <name>AddToPlaylistDialog</name>
    <message>
        <location filename="../AddToPlaylistDialog.qml" line="31"/>
        <source>Add To Playlist</source>
        <translation>Добавить В Плейлист</translation>
    </message>
</context>
<context>
    <name>ArchiveListView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Мульти-выбор</translation>
    </message>
    <message>
        <source>Delete from archive</source>
        <translation type="obsolete">Удалить из архива</translation>
    </message>
    <message>
        <source>Delete from device</source>
        <translation type="obsolete">Удалить с устройства</translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="64"/>
        <source>Deleted from archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="67"/>
        <location filename="../ArchiveListView.qml" line="86"/>
        <source>Unable to delete from archive</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BusyDialog</name>
    <message>
        <location filename="../BusyDialog.qml" line="47"/>
        <source>Loading...</source>
        <translation>Загрузка...</translation>
    </message>
</context>
<context>
    <name>ChangeUserDialog</name>
    <message>
        <location filename="../ChangeUserDialog.qml" line="50"/>
        <source>Change Current User</source>
        <translation>Сменить Текущего Пользователя</translation>
    </message>
</context>
<context>
    <name>CommentsDelegate</name>
    <message>
        <location filename="../CommentsDelegate.qml" line="20"/>
        <location filename="../CommentsDelegate.qml" line="22"/>
        <source>By </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../CommentsDelegate.qml" line="21"/>
        <location filename="../CommentsDelegate.qml" line="23"/>
        <source> on </source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ConfirmExitDialog</name>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="47"/>
        <source>Hold it!</source>
        <translation>Внимание!</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="58"/>
        <source>cuteTube is currently downloading. Do you really want to exit?</source>
        <translation>Имеются активные загрузки. Вы действительно хотите выйти?</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="71"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="81"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <source>English</source>
        <translation type="obsolete">Английский</translation>
    </message>
    <message>
        <source>German</source>
        <translation type="obsolete">Немецкий</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation type="obsolete">Итальянский</translation>
    </message>
    <message>
        <source>Finnish</source>
        <translation type="obsolete">Финский</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="222"/>
        <source>Video deleted from device</source>
        <translation>Видео удалено с устройства</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="225"/>
        <source>Unable to delete video</source>
        <translation>Невозможно удалить видео</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="229"/>
        <source>Video not found</source>
        <translation>Видео не найдено</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="284"/>
        <source>Copied to clipboard</source>
        <translation>Скопировано в буфер</translation>
    </message>
</context>
<context>
    <name>DownloadListDelegate</name>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Пауза</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation type="obsolete">В очереди</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation type="obsolete">Ошибка</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Загружается</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>Failed</source>
        <translation type="obsolete">Ошибка</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Загружается</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Пауза</translation>
    </message>
</context>
<context>
    <name>FileChooserDialog</name>
    <message>
        <location filename="../FileChooserDialog.qml" line="29"/>
        <source>Choose Video File</source>
        <translation>Выберите Видео Фаил</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Настройки</translation>
    </message>
    <message>
        <source>Accounts</source>
        <translation type="obsolete">Аккаунты</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="obsolete">О приложении</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="124"/>
        <source>My Channel</source>
        <translation>Мой Канал</translation>
    </message>
    <message>
        <source>Most Recent</source>
        <translation type="obsolete">Последние</translation>
    </message>
    <message>
        <source>Most Viewed</source>
        <translation type="obsolete">Популярные</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="194"/>
        <source>Archive</source>
        <translation>Архив</translation>
    </message>
</context>
<context>
    <name>InboxDelegate</name>
    <message>
        <location filename="../InboxDelegate.qml" line="44"/>
        <location filename="../InboxDelegate.qml" line="46"/>
        <source>From </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="45"/>
        <location filename="../InboxDelegate.qml" line="47"/>
        <location filename="../InboxDelegate.qml" line="95"/>
        <source> on </source>
        <translation type="unfinished"> от </translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="95"/>
        <source>By </source>
        <translation type="unfinished">От </translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="145"/>
        <source>Views</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InboxDialog</name>
    <message>
        <location filename="../InboxDialog.qml" line="57"/>
        <source>Inbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InboxDialog.qml" line="69"/>
        <source>No messages found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuBar</name>
    <message>
        <source>Menu</source>
        <translation type="obsolete">Меню</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="obsolete">Назад</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Выход</translation>
    </message>
    <message>
        <location filename="../MenuBar.qml" line="133"/>
        <source>Sort</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MyAccountView</name>
    <message>
        <source>Upload video</source>
        <translation type="obsolete">Загрузить видео</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="98"/>
        <source>My Uploads</source>
        <translation>Загруженные</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="104"/>
        <source>Uploads</source>
        <translation>Загруженные</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="122"/>
        <source>My Favourites</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="128"/>
        <source>Favourites</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="152"/>
        <source>Playlists</source>
        <translation>Плейлисты</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="176"/>
        <source>Subscriptions</source>
        <translation>Подписки</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="191"/>
        <source>Signed in as:</source>
        <translation>Вы вошли как:</translation>
    </message>
</context>
<context>
    <name>NewPlaylistDialog</name>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="34"/>
        <source>New Playlist</source>
        <translation>Новый Плейлист</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="46"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="59"/>
        <source>Description (optional)</source>
        <translation>Описание (не обязательно)</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="71"/>
        <source>Private?</source>
        <translation>Частное?</translation>
    </message>
</context>
<context>
    <name>NoAccountDialog</name>
    <message>
        <location filename="../NoAccountDialog.qml" line="60"/>
        <source>Hi there!</source>
        <translation>Привет!</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="71"/>
        <source>My name&apos;s Cutey. My buddy Clippy tells me it&apos;s the first time you&apos;ve used cuteTube. Would you like to add a YouTube account?</source>
        <translation>Меня зовут Милашка. Мой друг Скрепка сказал мне, что ты первый раз используешь cuteTube. Хочешь добавить аккаунт YouTube?</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="84"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="98"/>
        <source>Go Away</source>
        <translation>Выйти</translation>
    </message>
</context>
<context>
    <name>NotificationArea</name>
    <message>
        <location filename="../NotificationArea.qml" line="55"/>
        <source>No active downloads</source>
        <translation>Нет активных загрузок</translation>
    </message>
    <message>
        <location filename="../NotificationArea.qml" line="151"/>
        <source>Downloads</source>
        <translation>Загрузки</translation>
    </message>
</context>
<context>
    <name>OAuthDialog</name>
    <message>
        <location filename="../OAuthDialog.qml" line="8"/>
        <source>Authorisation For </source>
        <translation>Авторизация</translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="27"/>
        <source>Error obtaining facebook authorisation</source>
        <translation>Ошибка получения авторизации Facebook</translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="117"/>
        <source>Enter pin code</source>
        <translation>Введите пин код</translation>
    </message>
</context>
<context>
    <name>PlaylistDelegate</name>
    <message>
        <location filename="../PlaylistDelegate.qml" line="31"/>
        <source> videos</source>
        <translation> видео</translation>
    </message>
</context>
<context>
    <name>PlaylistVideosView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Мульти-выбор</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Загрузить видео</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Загрузить аудио</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Добавить в избранное</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Добавить в плейлист</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Скопировать в буфер</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="71"/>
        <source>Video(s) deleted from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="92"/>
        <source>No videos found</source>
        <translation>Видео не найдено</translation>
    </message>
</context>
<context>
    <name>PlaylistsView</name>
    <message>
        <location filename="../PlaylistsView.qml" line="58"/>
        <source>New playlist created</source>
        <translation>Новый плейлист создан</translation>
    </message>
    <message>
        <source>New playlist</source>
        <translation type="obsolete">Новый плейлист</translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="106"/>
        <source>No playlists found</source>
        <translation>Плейлисты не найдены</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <location filename="../ProxyDialog.qml" line="30"/>
        <source>Network Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="44"/>
        <source>Host (e.g. 192.168.100.1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="51"/>
        <source>Port (e.g. 8080)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Date</source>
        <translation type="obsolete">Дате</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation type="obsolete">Релевантности</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation type="obsolete">Рейтингу</translation>
    </message>
    <message>
        <source>Views</source>
        <translation type="obsolete">Просмотрам</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="183"/>
        <source>Order by:</source>
        <translation>Сортировать по:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../SettingsDialog.qml" line="217"/>
        <source>Your saved searches have been cleared</source>
        <translation>Сохраненные поисковые запросы очищены</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="220"/>
        <source>Database error. Unable to clear searches</source>
        <translation>Ошибка базы данных. Невозможно очистить запросы</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="267"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="333"/>
        <source>Playback quality</source>
        <translation>Качество проигрывания</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="342"/>
        <source>Download quality</source>
        <translation>Качество загрузки</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="308"/>
        <source>Start downloads</source>
        <translation>Начать загрузки</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="410"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="435"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="443"/>
        <source>Download location</source>
        <translation>Директория загрузки</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="452"/>
        <source>Screen orientation</source>
        <translation>Ориентация экрана</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="324"/>
        <source>Media player</source>
        <translation>Проигрыватель</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="193"/>
        <location filename="../SettingsDialog.qml" line="427"/>
        <location filename="../SettingsDialog.qml" line="429"/>
        <source>Language</source>
        <translation>Язык</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>High quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>360p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>480p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>720p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Dutch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Polish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="48"/>
        <source>Most recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="48"/>
        <source>Most viewed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="49"/>
        <source>Archive</source>
        <translation type="unfinished">Архив</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="49"/>
        <source>Latest subscription videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="50"/>
        <source>My uploads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="50"/>
        <source>My favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="136"/>
        <location filename="../SettingsDialog.qml" line="196"/>
        <source>Network Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="160"/>
        <location filename="../SettingsDialog.qml" line="335"/>
        <source>Playback Quality</source>
        <translation>Качество Проигрывания</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="163"/>
        <location filename="../SettingsDialog.qml" line="344"/>
        <source>Download Quality</source>
        <translation>Качество Загрузки</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="166"/>
        <location filename="../SettingsDialog.qml" line="310"/>
        <source>Start Downloads</source>
        <translation>Начать Загрузки</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="172"/>
        <location filename="../SettingsDialog.qml" line="360"/>
        <source>Category Feed One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="175"/>
        <location filename="../SettingsDialog.qml" line="369"/>
        <source>Category Feed Two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="178"/>
        <location filename="../SettingsDialog.qml" line="378"/>
        <source>Order Category Videos By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="184"/>
        <location filename="../SettingsDialog.qml" line="454"/>
        <source>Screen Orientation</source>
        <translation>Ориентация Экрана</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="187"/>
        <location filename="../SettingsDialog.qml" line="326"/>
        <source>Media Player</source>
        <translation>Проигрыватель</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="350"/>
        <source>YouTube categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="358"/>
        <source>Category feed one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="367"/>
        <source>Category feed two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="376"/>
        <source>Order category videos by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="468"/>
        <source>Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="476"/>
        <source>Feed one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="485"/>
        <source>Feed two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="494"/>
        <source>Feed three</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="503"/>
        <source>Feed four</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Mobile</source>
        <translation>Мобильное</translation>
    </message>
    <message>
        <source>High Quality</source>
        <translation type="obsolete">Высокое Качество</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Automatically</source>
        <translation>Автоматически</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Manually</source>
        <translation>Вручную</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>On</source>
        <translation>Вкл</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Off</source>
        <translation>Выкл</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Automatic</source>
        <translation>Автоматически</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Landscape</source>
        <translation>Ландшафтная</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Portrait</source>
        <translation>Портретная</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Light</source>
        <translation>Светлая</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Dark</source>
        <translation>Темная</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>English</source>
        <translation>Английский</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>German</source>
        <translation>Немецкий</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Finnish</source>
        <translation>Финский</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Italian</source>
        <translation>Итальянский</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation type="obsolete">В очереди</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Пауза</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="121"/>
        <source>Your settings have been saved</source>
        <translation>Настройки сохранены</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="126"/>
        <location filename="../SettingsDialog.qml" line="169"/>
        <source>Download Path</source>
        <translation>Директория Загрузки</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="128"/>
        <source>Download Location</source>
        <translation>Директория Загрузки</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="181"/>
        <location filename="../SettingsDialog.qml" line="394"/>
        <source>Safe Search</source>
        <translation>Безопасный Поиск</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="190"/>
        <location filename="../SettingsDialog.qml" line="418"/>
        <location filename="../SettingsDialog.qml" line="420"/>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="199"/>
        <location filename="../SettingsDialog.qml" line="478"/>
        <source>Widget Feed One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="202"/>
        <location filename="../SettingsDialog.qml" line="487"/>
        <source>Widget Feed Two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="205"/>
        <location filename="../SettingsDialog.qml" line="496"/>
        <source>Widget Feed Three</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="208"/>
        <location filename="../SettingsDialog.qml" line="505"/>
        <source>Widget Feed Four</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="291"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="299"/>
        <source>Network proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="316"/>
        <source>Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="384"/>
        <source>YouTube searches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="392"/>
        <source>Safe search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="300"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="403"/>
        <source>Clear saved searches</source>
        <translation>Очистить поисковые запросы</translation>
    </message>
</context>
<context>
    <name>Sharing</name>
    <message>
        <location filename="../../../sharing.cpp" line="78"/>
        <source>Error - Server repsonse is: </source>
        <translation>Ошибка - Ответ сервера: </translation>
    </message>
</context>
<context>
    <name>SubscriptionsView</name>
    <message>
        <location filename="../SubscriptionsView.qml" line="36"/>
        <source>Latest Subscriptions Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="45"/>
        <source>You have unsubscribed to this channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have unsubscribed to &apos;</source>
        <translation type="obsolete">Вы больше не подписаны на &apos;</translation>
    </message>
    <message>
        <source>Latest Subscription Videos</source>
        <translation type="obsolete">Последнее в подписках</translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="104"/>
        <source>No subscriptions found</source>
        <translation>Подписок не найдено</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../UploadDialog.qml" line="70"/>
        <source>Cars &amp; Vehicles</source>
        <translation>Автомобили и Транспорт</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="70"/>
        <source>Comedy</source>
        <translation>Юмор</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="71"/>
        <source>Education</source>
        <translation>Образование</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <location filename="../UploadDialog.qml" line="71"/>
        <source>Entertainment</source>
        <translation>Развлечения</translation>
    </message>
    <message>
        <source>Film and Animation</source>
        <translation type="obsolete">Фильмы и Анимация</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="72"/>
        <source>Gaming</source>
        <translation>Игры</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="72"/>
        <source>Film &amp; Animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>Howto &amp; Style</source>
        <translation>Обучение и стиль</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>News &amp; Politics</source>
        <translation>Новости и политика</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="74"/>
        <source>Non-profits &amp; Activism</source>
        <translation>Общественные акции</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="74"/>
        <source>People &amp; Blogs</source>
        <translation>Люди и блоги</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="75"/>
        <source>Pets &amp; Animals</source>
        <translation>Животные</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="75"/>
        <source>Science &amp; Technology</source>
        <translation>Наука и техника</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="76"/>
        <source>Sport</source>
        <translation>Спорт</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="76"/>
        <source>Travel &amp; Events</source>
        <translation>Путешествия и события</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="29"/>
        <location filename="../UploadDialog.qml" line="220"/>
        <source>Category</source>
        <translation>Категория</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="118"/>
        <source>Upload Video</source>
        <translation>Загрузить Видео</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="143"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="152"/>
        <location filename="../UploadDialog.qml" line="228"/>
        <source>None chosen</source>
        <translation>Не выбрано</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="168"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="181"/>
        <source>Description (optional)</source>
        <translation>Описание (не обязательно)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="193"/>
        <source>Tags (seperated by commas)</source>
        <translation>Теги (через запятую)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="206"/>
        <source>Private?</source>
        <translation>Частное?</translation>
    </message>
</context>
<context>
    <name>UploadProgressDialog</name>
    <message>
        <location filename="../UploadProgressDialog.qml" line="6"/>
        <source>Starting upload</source>
        <translation>Начинаю загрузку</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="30"/>
        <source>Upload Progress</source>
        <translation>Прогресс Загрузки</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="42"/>
        <source>Filename</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="57"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Abort</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <location filename="../UploadProgressDialog.qml" line="97"/>
        <location filename="../UploadProgressDialog.qml" line="115"/>
        <source>Upload is in progress</source>
        <translation>Загрузка в процессе</translation>
    </message>
</context>
<context>
    <name>UserInfoDialog</name>
    <message>
        <location filename="../UserInfoDialog.qml" line="106"/>
        <source>Profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="152"/>
        <source>Uploads</source>
        <translation type="unfinished">Загруженные</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="158"/>
        <source>Subscribers</source>
        <translation>Подписчики</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="178"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="184"/>
        <source>Age</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="197"/>
        <location filename="../UserInfoDialog.qml" line="215"/>
        <location filename="../UserInfoDialog.qml" line="221"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="203"/>
        <source>Gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="209"/>
        <source>Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="215"/>
        <source>Male</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="215"/>
        <source>Female</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="236"/>
        <source>About</source>
        <translation type="unfinished">О приложении</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="253"/>
        <source>No info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="268"/>
        <source>Unsubscribe</source>
        <translation type="unfinished">Отписаться</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="268"/>
        <source>Subscribe</source>
        <translation type="unfinished">Подписаться</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="obsolete">Ролики</translation>
    </message>
</context>
<context>
    <name>UserVideosView</name>
    <message>
        <location filename="../UserVideosView.qml" line="131"/>
        <source>You have subscribed to &apos;</source>
        <translation>Вы подписались на &apos;</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="135"/>
        <source>You have unsubscribed to &apos;</source>
        <translation>Вы больше не подписаны на &apos;</translation>
    </message>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Мульти-выбор</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Загрузить видео</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Загрузить аудио</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Добавить в избранное</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Добавить в плейлист</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Копировать в буфер</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="155"/>
        <source>No videos found</source>
        <translation>Видео не найдено</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="214"/>
        <source>Subscribers</source>
        <translation>Подписчики</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="228"/>
        <source>Videos</source>
        <translation>Видео</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="251"/>
        <source>Unsubscribe</source>
        <translation>Отписаться</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="251"/>
        <source>Subscribe</source>
        <translation>Подписаться</translation>
    </message>
</context>
<context>
    <name>VideoInfoView</name>
    <message>
        <location filename="../VideoInfoView.qml" line="15"/>
        <source>No description</source>
        <translation>Нет описания</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="93"/>
        <source>Your comment has been added</source>
        <translation>Ваш комментарий добавлен</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="96"/>
        <source>Your rating has been added</source>
        <translation>Ваша оценка добавлена</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="103"/>
        <source>Video shared on facebook</source>
        <translation>Видео опубликовано на Facebook</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Добавить в избранное</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Добавить в плейлист</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Копировать в буфер</translation>
    </message>
    <message>
        <source>Share via facebook</source>
        <translation type="obsolete">Опубликовать на Facebook</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="439"/>
        <location filename="../VideoInfoView.qml" line="464"/>
        <location filename="../VideoInfoView.qml" line="578"/>
        <source>You are not signed in to a YouTube account</source>
        <translation>Вы не вошли в аккаунт YouTube</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="245"/>
        <source>Info</source>
        <translation>Инфо</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="284"/>
        <source>Comments</source>
        <translation>Комментарий</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="323"/>
        <source>Related</source>
        <translation>Похожие</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="408"/>
        <location filename="../VideoInfoView.qml" line="411"/>
        <source>By </source>
        <translation>От </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="410"/>
        <location filename="../VideoInfoView.qml" line="413"/>
        <source> on </source>
        <translation> от </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="481"/>
        <source>Views</source>
        <translation>Просмотров</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="495"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="511"/>
        <source>Tags</source>
        <translation>Теги</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="521"/>
        <source>No tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="590"/>
        <source>No comments</source>
        <translation>Нет комментариев</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="590"/>
        <source> comments</source>
        <translation> комментариев</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="706"/>
        <source>No related videos</source>
        <translation>Нет похожих видео</translation>
    </message>
</context>
<context>
    <name>VideoListDelegate</name>
    <message>
        <location filename="../VideoListDelegate.qml" line="52"/>
        <source>By </source>
        <translation>От </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="52"/>
        <source> on </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="102"/>
        <source>Views</source>
        <translation>Просмотров</translation>
    </message>
</context>
<context>
    <name>VideoListView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Мульти-выбор</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Скачать видео</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Скачать аудио</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Добавить в избранное</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Добавить в плейлист</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Копировать в буфер</translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="82"/>
        <source>Video(s) deleted from favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="104"/>
        <source>No videos found</source>
        <translation>Видео не найдены</translation>
    </message>
</context>
<context>
    <name>VideoPlaybackView</name>
    <message>
        <source>Error: Unable to retrieve video</source>
        <translation type="obsolete">Ошибка: Невозможно получить видео</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>No videos found</source>
        <translation type="obsolete">Не найдено видео</translation>
    </message>
</context>
<context>
    <name>YouTube</name>
    <message>
        <location filename="../../../youtube.cpp" line="43"/>
        <source>Error obtaining access token</source>
        <translation>Ошибка при получении токена</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="54"/>
        <source>Authentication failed</source>
        <translation>Ошибка аутентификации</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="58"/>
        <source>You are signed in to YouTube as &apos;</source>
        <translation>Вы вошли на YouTube как &apos;</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="120"/>
        <location filename="../../../youtube.cpp" line="226"/>
        <source>Error - Server repsonse is: </source>
        <translation>Ошибка - Ответ сервера:</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="170"/>
        <location filename="../../../youtube.cpp" line="178"/>
        <source>Upload aborted</source>
        <translation>Загрузка отменена</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="185"/>
        <source>Upload interrupted. Attempting to resume...</source>
        <translation>Загрузка прервана. Попытка возобновить...</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="189"/>
        <source>Upload failed</source>
        <translation>Ошибка загрузки</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="195"/>
        <source>Upload is completed</source>
        <translation>Загрузка завершена</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="397"/>
        <location filename="../../../youtube.cpp" line="439"/>
        <source>Error: Unable to retrieve video</source>
        <translation>Ошибка: Невозможно получить видео</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dark</source>
        <translation type="obsolete">Темная</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="obsolete">Светлая</translation>
    </message>
    <message>
        <location filename="../main.qml" line="157"/>
        <source>Video(s) added to download queue</source>
        <translation>Видео добавлено(ы) в очередь загрузки</translation>
    </message>
    <message>
        <location filename="../main.qml" line="160"/>
        <source>Video(s) already in download queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="171"/>
        <source>Audio track(s) added to download queue</source>
        <translation>Аудио добавлено(ы) в очередь загрузки</translation>
    </message>
    <message>
        <location filename="../main.qml" line="174"/>
        <source>Audio track(s) already in download queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video added to favourites</source>
        <translation type="obsolete">Видео добавлено в избранное</translation>
    </message>
    <message>
        <source>Video added to playlist</source>
        <translation type="obsolete">Видео добавлено в плейлист</translation>
    </message>
    <message>
        <location filename="../main.qml" line="214"/>
        <source>New playlist created</source>
        <translation>Новый плейлист создан</translation>
    </message>
    <message>
        <location filename="../main.qml" line="279"/>
        <source>Converting</source>
        <translation>Конвертирую</translation>
    </message>
    <message>
        <location filename="../main.qml" line="264"/>
        <source>Conversion of &apos;</source>
        <translation>Конвертация &apos;</translation>
    </message>
    <message>
        <location filename="../main.qml" line="33"/>
        <source>Cars &amp; Vehicles</source>
        <translation type="unfinished">Автомобили и Транспорт</translation>
    </message>
    <message>
        <location filename="../main.qml" line="33"/>
        <source>Comedy</source>
        <translation type="unfinished">Юмор</translation>
    </message>
    <message>
        <location filename="../main.qml" line="34"/>
        <source>Education</source>
        <translation type="unfinished">Образование</translation>
    </message>
    <message>
        <location filename="../main.qml" line="34"/>
        <source>Entertainment</source>
        <translation type="unfinished">Развлечения</translation>
    </message>
    <message>
        <location filename="../main.qml" line="35"/>
        <source>Film &amp; Animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="35"/>
        <source>Gaming</source>
        <translation type="unfinished">Игры</translation>
    </message>
    <message>
        <location filename="../main.qml" line="36"/>
        <source>Howto &amp; Style</source>
        <translation type="unfinished">Обучение и стиль</translation>
    </message>
    <message>
        <location filename="../main.qml" line="36"/>
        <source>Music</source>
        <translation type="unfinished">Музыка</translation>
    </message>
    <message>
        <location filename="../main.qml" line="36"/>
        <source>News &amp; Politics</source>
        <translation type="unfinished">Новости и политика</translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>Non-profits &amp; Activism</source>
        <translation type="unfinished">Общественные акции</translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>People &amp; Blogs</source>
        <translation type="unfinished">Люди и блоги</translation>
    </message>
    <message>
        <location filename="../main.qml" line="38"/>
        <source>Pets &amp; Animals</source>
        <translation type="unfinished">Животные</translation>
    </message>
    <message>
        <location filename="../main.qml" line="38"/>
        <source>Science &amp; Technology</source>
        <translation type="unfinished">Наука и техника</translation>
    </message>
    <message>
        <location filename="../main.qml" line="39"/>
        <source>Sport</source>
        <translation type="unfinished">Спорт</translation>
    </message>
    <message>
        <location filename="../main.qml" line="39"/>
        <source>Travel &amp; Events</source>
        <translation type="unfinished">Путешествия и события</translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Relevance</source>
        <translation type="unfinished">Релевантности</translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Rating</source>
        <translation type="unfinished">Рейтингу</translation>
    </message>
    <message>
        <location filename="../main.qml" line="205"/>
        <source>Video(s) added to favourites</source>
        <translation>Видео добавлено в избранное</translation>
    </message>
    <message>
        <location filename="../main.qml" line="206"/>
        <source>Video(s) added to playlist</source>
        <translation>Видео добавлено в плейлист</translation>
    </message>
    <message>
        <location filename="../main.qml" line="264"/>
        <source>&apos; failed</source>
        <translation>&apos; не выполнена</translation>
    </message>
    <message>
        <source>Mobile</source>
        <translation type="obsolete">Мобильное</translation>
    </message>
    <message>
        <location filename="../main.qml" line="279"/>
        <source>Queued</source>
        <translation>В очереди</translation>
    </message>
    <message>
        <location filename="../main.qml" line="279"/>
        <source>Paused</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <location filename="../main.qml" line="279"/>
        <source>Downloading</source>
        <translation>Загружается</translation>
    </message>
    <message>
        <location filename="../main.qml" line="279"/>
        <source>Failed</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../main.qml" line="40"/>
        <source>Most Recent</source>
        <translation>Последние</translation>
    </message>
    <message>
        <location filename="../main.qml" line="40"/>
        <source>Most Viewed</source>
        <translation>Популярные</translation>
    </message>
</context>
<context>
    <name>mainscripts</name>
    <message>
        <source>Media Player</source>
        <translation type="obsolete">Проигрыватель</translation>
    </message>
    <message>
        <source>My Channel</source>
        <translation type="obsolete">Мой Канал</translation>
    </message>
    <message>
        <source>Archive</source>
        <translation type="obsolete">Архив</translation>
    </message>
    <message>
        <source>My Playlists</source>
        <translation type="obsolete">Мой Плейлисты</translation>
    </message>
    <message>
        <source>My Subscriptions</source>
        <translation type="obsolete">Мои Подписки</translation>
    </message>
    <message>
        <source>Video Info</source>
        <translation type="obsolete">Информация</translation>
    </message>
    <message>
        <source>Video Playback</source>
        <translation type="obsolete">Качество Видео</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="obsolete">Загрузки</translation>
    </message>
    <message>
        <source>date</source>
        <translation type="obsolete">дате</translation>
    </message>
    <message>
        <source>views</source>
        <translation type="obsolete">просмотрам</translation>
    </message>
    <message>
        <source>relevance</source>
        <translation type="obsolete">релевантности</translation>
    </message>
    <message>
        <source>rating</source>
        <translation type="obsolete">рейтингу</translation>
    </message>
    <message>
        <source>Search </source>
        <translation type="obsolete">Поиск </translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <source>High Quality</source>
        <translation type="obsolete">Высокое Качество</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Пауза</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="obsolete">Автоматически</translation>
    </message>
    <message>
        <source>Media Player</source>
        <translation type="obsolete">Проигрыватель</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="obsolete">Дата</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="obsolete">Темная</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">Английский</translation>
    </message>
</context>
</TS>
